==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/pl/hebrew.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "w tym kwartale",
	"field-quarter-short-relative+1": "w przyszłym kwartale",
	"field-tue-relative+-1": "w zeszły wtorek",
	"field-year": "rok",
	"field-wed-relative+0": "w tę środę",
	"field-wed-relative+1": "w przyszłą środę",
	"field-minute": "minuta",
	"field-tue-narrow-relative+0": "w ten wtorek",
	"field-tue-narrow-relative+1": "w przyszły wtorek",
	"field-thu-short-relative+0": "w ten czwartek",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "w przyszły czwartek",
	"field-day-relative+0": "dzisiaj",
	"field-day-relative+1": "jutro",
	"field-day-relative+2": "pojutrze",
	"field-wed-narrow-relative+-1": "w zeszłą środę",
	"field-year-narrow": "r.",
	"field-tue-relative+0": "w ten wtorek",
	"field-tue-relative+1": "w przyszły wtorek",
	"field-second-short": "sek.",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "w tym tygodniu",
	"field-month-relative+0": "w tym miesiącu",
	"field-week-relative+1": "w przyszłym tygodniu",
	"field-month-relative+1": "w przyszłym miesiącu",
	"field-sun-narrow-relative+0": "w tę niedzielę",
	"field-mon-short-relative+0": "w ten poniedziałek",
	"field-sun-narrow-relative+1": "w przyszłą niedzielę",
	"field-mon-short-relative+1": "w przyszły poniedziałek",
	"field-second-relative+0": "teraz",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-month-short": "mies.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d.MM.y G",
	"field-day": "dzień",
	"field-year-relative+-1": "w zeszłym roku",
	"field-sat-short-relative+-1": "w zeszłą sobotę",
	"field-hour-relative+0": "ta godzina",
	"dateFormatItem-yyyyMEd": "E, d.MM.y G",
	"field-wed-relative+-1": "w zeszłą środę",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "w zeszłą sobotę",
	"field-second": "sekunda",
	"days-standAlone-narrow": [
		"N",
		"P",
		"W",
		"Ś",
		"C",
		"P",
		"S"
	],
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "kwartał",
	"field-week-short": "tydz.",
	"quarters-standAlone-wide": [
		"I kwartał",
		"II kwartał",
		"III kwartał",
		"IV kwartał"
	],
	"days-format-narrow": [
		"n",
		"p",
		"w",
		"ś",
		"c",
		"p",
		"s"
	],
	"field-tue-short-relative+0": "w ten wtorek",
	"field-tue-short-relative+1": "w przyszły wtorek",
	"field-mon-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-month": "miesiąc",
	"field-day-narrow": "dzień",
	"field-minute-short": "min",
	"field-dayperiod": "rano / po południu / wieczorem",
	"field-sat-short-relative+0": "w tę sobotę",
	"field-sat-short-relative+1": "w przyszłą sobotę",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"quarters-standAlone-abbr": [
		"I kw.",
		"II kw.",
		"III kw.",
		"IV kw."
	],
	"dateFormatItem-yyyyM": "MM.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "w ten poniedziałek",
	"field-mon-relative+1": "w przyszły poniedziałek",
	"field-year-short": "r.",
	"field-quarter-relative+-1": "w zeszłym kwartale",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dayPeriods-standAlone-narrow-am": "a",
	"days-format-short": [
		"nie",
		"pon",
		"wto",
		"śro",
		"czw",
		"pią",
		"sob"
	],
	"field-sat-relative+-1": "w zeszłą sobotę",
	"dateTimeFormat-long": "{1}, {0}",
	"dateFormatItem-Md": "d.MM",
	"field-hour": "godzina",
	"months-format-wide": [
		"Tiszri",
		"Cheszwan",
		"Kislew",
		"Tewet",
		"Szwat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijar",
		"Siwan",
		"Tamuz",
		"Aw",
		"Elul"
	],
	"dateFormat-full": "EEEE, d MMMM y G",
	"field-month-relative+-1": "w zeszłym miesiącu",
	"field-quarter-short": "kw.",
	"field-sat-narrow-relative+0": "w tę sobotę",
	"field-fri-relative+0": "w ten piątek",
	"field-sat-narrow-relative+1": "w przyszłą sobotę",
	"field-fri-relative+1": "w przyszły piątek",
	"field-sun-short-relative+0": "w tę niedzielę",
	"field-sun-short-relative+1": "w przyszłą niedzielę",
	"field-week-relative+-1": "w zeszłym tygodniu",
	"field-quarter-short-relative+-1": "w zeszłym kwartale",
	"months-format-abbr": [
		"Tiszri",
		"Cheszwan",
		"Kislew",
		"Tewet",
		"Szwat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijar",
		"Siwan",
		"Tamuz",
		"Aw",
		"Elul"
	],
	"field-quarter-relative+0": "w tym kwartale",
	"field-minute-relative+0": "ta minuta",
	"field-quarter-relative+1": "w przyszłym kwartale",
	"field-wed-short-relative+-1": "w zeszłą środę",
	"dateFormat-short": "dd.MM.y G",
	"field-thu-short-relative+-1": "w zeszły czwartek",
	"days-standAlone-wide": [
		"niedziela",
		"poniedziałek",
		"wtorek",
		"środa",
		"czwartek",
		"piątek",
		"sobota"
	],
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "w zeszły czwartek",
	"field-tue-narrow-relative+-1": "w zeszły wtorek",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "p",
	"field-wed-short-relative+0": "w tę środę",
	"months-standAlone-wide": [
		"Tiszri",
		"Cheszwan",
		"Kislew",
		"Tewet",
		"Szwat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijar",
		"Siwan",
		"Tamuz",
		"Aw",
		"Elul"
	],
	"field-wed-short-relative+1": "w przyszłą środę",
	"field-sun-relative+-1": "w zeszłą niedzielę",
	"days-standAlone-abbr": [
		"niedz.",
		"pon.",
		"wt.",
		"śr.",
		"czw.",
		"pt.",
		"sob."
	],
	"dateTimeFormat-full": "{1}, {0}",
	"dateFormatItem-hm": "hh:mm a",
	"months-format-abbr-leap": "Adar II",
	"field-weekday": "dzień tygodnia",
	"field-quarter-narrow-relative+0": "w tym kwartale",
	"field-sat-relative+0": "w tę sobotę",
	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
	"dateFormatItem-h": "hh a",
	"field-sat-relative+1": "w przyszłą sobotę",
	"months-standAlone-abbr": [
		"Tiszri",
		"Cheszwan",
		"Kislew",
		"Tewet",
		"Szwat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijar",
		"Siwan",
		"Tamuz",
		"Aw",
		"Elul"
	],
	"months-format-wide-leap": "Adar II",
	"dateFormatItem-MEd": "E, d.MM",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "w ten czwartek",
	"field-thu-narrow-relative+1": "w przyszły czwartek",
	"field-sun-narrow-relative+-1": "w zeszłą niedzielę",
	"field-mon-short-relative+-1": "w zeszły poniedziałek",
	"field-thu-relative+0": "w ten czwartek",
	"field-thu-relative+1": "w przyszły czwartek",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "w zeszły piątek",
	"field-thu-relative+-1": "w zeszły czwartek",
	"field-week": "tydzień",
	"quarters-format-wide": [
		"I kwartał",
		"II kwartał",
		"III kwartał",
		"IV kwartał"
	],
	"dateFormatItem-Ed": "E, d",
	"field-wed-narrow-relative+0": "w tę środę",
	"field-wed-narrow-relative+1": "w przyszłą środę",
	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"field-fri-short-relative+0": "w ten piątek",
	"field-fri-short-relative+1": "w przyszły piątek",
	"days-standAlone-short": [
		"nie",
		"pon",
		"wto",
		"śro",
		"czw",
		"pią",
		"sob"
	],
	"months-standAlone-abbr-leap": "Adar II",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "godz.",
	"quarters-format-abbr": [
		"I kw.",
		"II kw.",
		"III kw.",
		"IV kw."
	],
	"field-month-narrow": "mc",
	"field-hour-narrow": "g.",
	"field-fri-narrow-relative+-1": "w zeszły piątek",
	"field-year-relative+0": "w tym roku",
	"field-year-relative+1": "w przyszłym roku",
	"field-fri-relative+-1": "w zeszły piątek",
	"field-tue-short-relative+-1": "w zeszły wtorek",
	"field-minute-narrow": "min",
	"days-format-wide": [
		"niedziela",
		"poniedziałek",
		"wtorek",
		"środa",
		"czwartek",
		"piątek",
		"sobota"
	],
	"field-mon-narrow-relative+0": "w ten poniedziałek",
	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
	"field-zone": "strefa czasowa",
	"dateFormatItem-MMMEd": "E, d MMM",
	"months-standAlone-wide-leap": "Adar II",
	"field-quarter-narrow": "kw.",
	"field-sun-short-relative+-1": "w zeszłą niedzielę",
	"field-day-relative+-1": "wczoraj",
	"field-day-relative+-2": "przedwczoraj",
	"days-format-abbr": [
		"niedz.",
		"pon.",
		"wt.",
		"śr.",
		"czw.",
		"pt.",
		"sob."
	],
	"field-sun-relative+0": "w tę niedzielę",
	"field-sun-relative+1": "w przyszłą niedzielę",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dzień",
	"field-week-narrow": "tydz.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "w ten piątek",
	"field-fri-narrow-relative+1": "w przyszły piątek"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/pl/hebrew.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "w tym kwartale",
	"field-quarter-short-relative+1": "w przyszłym kwartale",
	"field-tue-relative+-1": "w zeszły wtorek",
	"field-year": "rok",
	"field-wed-relative+0": "w tę środę",
	"field-wed-relative+1": "w przyszłą środę",
	"field-minute": "minuta",
	"field-month-narrow-relative+-1": "w zeszłym mies.",
	"field-tue-narrow-relative+0": "w ten wtorek",
	"field-tue-narrow-relative+1": "w przyszły wtorek",
	"field-thu-short-relative+0": "w ten czwartek",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "w przyszły czwartek",
	"field-day-relative+0": "dzisiaj",
	"field-day-short-relative+-2": "przedwczoraj",
	"field-day-relative+1": "jutro",
	"field-week-narrow-relative+0": "w tym tyg.",
	"field-day-relative+2": "pojutrze",
	"field-week-narrow-relative+1": "w przyszłym tyg.",
	"field-wed-narrow-relative+-1": "w zeszłą środę",
	"field-year-narrow": "r.",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "w tym roku",
	"field-tue-relative+0": "w ten wtorek",
	"field-year-narrow-relative+1": "w przyszłym roku",
	"field-tue-relative+1": "w przyszły wtorek",
	"field-weekdayOfMonth": "dzień miesiąca",
	"field-second-short": "sek.",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "dz. mies.",
	"field-week-relative+0": "w tym tygodniu",
	"field-month-relative+0": "w tym miesiącu",
	"field-week-relative+1": "w przyszłym tygodniu",
	"field-month-relative+1": "w przyszłym miesiącu",
	"field-sun-narrow-relative+0": "w tę niedzielę",
	"field-mon-short-relative+0": "w ten poniedziałek",
	"field-sun-narrow-relative+1": "w przyszłą niedzielę",
	"field-mon-short-relative+1": "w przyszły poniedziałek",
	"field-second-relative+0": "teraz",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "tydzień miesiąca",
	"field-month-short": "mies.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d.MM.y G",
	"field-day": "dzień",
	"field-dayOfYear-short": "dz. roku",
	"field-year-relative+-1": "w zeszłym roku",
	"field-sat-short-relative+-1": "w zeszłą sobotę",
	"field-hour-relative+0": "ta godzina",
	"dateFormatItem-yyyyMEd": "E, d.MM.y G",
	"field-wed-relative+-1": "w zeszłą środę",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "w zeszłą sobotę",
	"field-second": "sekunda",
	"days-standAlone-narrow": [
		"N",
		"P",
		"W",
		"Ś",
		"C",
		"P",
		"S"
	],
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "kwartał",
	"field-week-short": "tydz.",
	"field-day-narrow-relative+0": "dziś",
	"field-day-narrow-relative+1": "jutro",
	"field-day-narrow-relative+2": "pojutrze",
	"quarters-standAlone-wide": [
		"I kwartał",
		"II kwartał",
		"III kwartał",
		"IV kwartał"
	],
	"days-format-narrow": [
		"n",
		"p",
		"w",
		"ś",
		"c",
		"p",
		"s"
	],
	"field-tue-short-relative+0": "w ten wtorek",
	"field-tue-short-relative+1": "w przyszły wtorek",
	"field-month-short-relative+-1": "w zeszłym mies.",
	"field-mon-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-month": "miesiąc",
	"field-day-narrow": "d.",
	"field-minute-short": "min",
	"field-dayperiod": "rano / po południu / wieczorem",
	"field-sat-short-relative+0": "w tę sobotę",
	"field-sat-short-relative+1": "w przyszłą sobotę",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"quarters-standAlone-abbr": [
		"I kw.",
		"II kw.",
		"III kw.",
		"IV kw."
	],
	"dateFormatItem-yyyyM": "MM.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "w ten poniedziałek",
	"field-mon-relative+1": "w przyszły poniedziałek",
	"field-day-narrow-relative+-1": "wcz.",
	"field-year-short": "r.",
	"field-day-narrow-relative+-2": "przedwczoraj",
	"field-quarter-relative+-1": "w zeszłym kwartale",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "rano / po poł. / wiecz.",
	"dayPeriods-standAlone-narrow-am": "a",
	"field-week-narrow-relative+-1": "w zeszłym tyg.",
	"days-format-short": [
		"nie",
		"pon",
		"wto",
		"śro",
		"czw",
		"pią",
		"sob"
	],
	"field-dayOfYear": "dzień roku",
	"field-sat-relative+-1": "w zeszłą sobotę",
	"dateTimeFormat-long": "{1}, {0}",
	"dateFormatItem-Md": "d.MM",
	"field-hour": "godzina",
	"months-format-wide": [
		"Tiszri",
		"Cheszwan",
		"Kislew",
		"Tewet",
		"Szwat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijar",
		"Siwan",
		"Tamuz",
		"Aw",
		"Elul"
	],
	"dateFormat-full": "EEEE, d MMMM y G",
	"field-month-relative+-1": "w zeszłym miesiącu",
	"field-quarter-short": "kw.",
	"field-sat-narrow-relative+0": "w tę sobotę",
	"field-fri-relative+0": "w ten piątek",
	"field-sat-narrow-relative+1": "w przyszłą sobotę",
	"field-fri-relative+1": "w przyszły piątek",
	"field-month-narrow-relative+0": "w tym mies.",
	"field-month-narrow-relative+1": "w przyszłym mies.",
	"field-sun-short-relative+0": "w tę niedzielę",
	"field-sun-short-relative+1": "w przyszłą niedzielę",
	"field-week-relative+-1": "w zeszłym tygodniu",
	"field-quarter-short-relative+-1": "w zeszłym kwartale",
	"months-format-abbr": [
		"Tiszri",
		"Cheszwan",
		"Kislew",
		"Tewet",
		"Szwat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijar",
		"Siwan",
		"Tamuz",
		"Aw",
		"Elul"
	],
	"field-quarter-relative+0": "w tym kwartale",
	"field-minute-relative+0": "ta minuta",
	"field-quarter-relative+1": "w przyszłym kwartale",
	"field-wed-short-relative+-1": "w zeszłą środę",
	"dateFormat-short": "dd.MM.y G",
	"field-thu-short-relative+-1": "w zeszły czwartek",
	"field-year-narrow-relative+-1": "w zeszłym roku",
	"days-standAlone-wide": [
		"niedziela",
		"poniedziałek",
		"wtorek",
		"środa",
		"czwartek",
		"piątek",
		"sobota"
	],
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "w zeszły czwartek",
	"field-tue-narrow-relative+-1": "w zeszły wtorek",
	"field-weekOfMonth-short": "tydz. mies.",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "p",
	"field-wed-short-relative+0": "w tę środę",
	"months-standAlone-wide": [
		"Tiszri",
		"Cheszwan",
		"Kislew",
		"Tewet",
		"Szwat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijar",
		"Siwan",
		"Tamuz",
		"Aw",
		"Elul"
	],
	"field-wed-short-relative+1": "w przyszłą środę",
	"field-sun-relative+-1": "w zeszłą niedzielę",
	"days-standAlone-abbr": [
		"niedz.",
		"pon.",
		"wt.",
		"śr.",
		"czw.",
		"pt.",
		"sob."
	],
	"dateTimeFormat-full": "{1}, {0}",
	"dateFormatItem-hm": "hh:mm a",
	"months-format-abbr-leap": "Adar II",
	"field-weekday": "dzień tygodnia",
	"field-quarter-narrow-relative+0": "w tym kwartale",
	"field-sat-relative+0": "w tę sobotę",
	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
	"field-sat-relative+1": "w przyszłą sobotę",
	"field-day-short-relative+2": "pojutrze",
	"dateFormatItem-h": "hh a",
	"field-week-short-relative+0": "w tym tyg.",
	"field-week-short-relative+1": "w przyszłym tyg.",
	"months-standAlone-abbr": [
		"Tiszri",
		"Cheszwan",
		"Kislew",
		"Tewet",
		"Szwat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijar",
		"Siwan",
		"Tamuz",
		"Aw",
		"Elul"
	],
	"months-format-wide-leap": "Adar II",
	"field-dayOfYear-narrow": "dz. r.",
	"field-month-short-relative+0": "w tym mies.",
	"field-month-short-relative+1": "w przyszłym mies.",
	"field-weekdayOfMonth-short": "dzień mies.",
	"dateFormatItem-MEd": "E, d.MM",
	"field-zone-narrow": "str. czas.",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "w ten czwartek",
	"field-thu-narrow-relative+1": "w przyszły czwartek",
	"field-sun-narrow-relative+-1": "w zeszłą niedzielę",
	"field-mon-short-relative+-1": "w zeszły poniedziałek",
	"field-thu-relative+0": "w ten czwartek",
	"field-thu-relative+1": "w przyszły czwartek",
	"field-fri-short-relative+-1": "w zeszły piątek",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-thu-relative+-1": "w zeszły czwartek",
	"field-week": "tydzień",
	"quarters-format-wide": [
		"I kwartał",
		"II kwartał",
		"III kwartał",
		"IV kwartał"
	],
	"dateFormatItem-Ed": "E, d",
	"field-wed-narrow-relative+0": "w tę środę",
	"field-wed-narrow-relative+1": "w przyszłą środę",
	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
	"field-year-short-relative+0": "w tym roku",
	"field-dayperiod-short": "rano / po południu / wieczorem",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"field-year-short-relative+1": "w przyszłym roku",
	"field-fri-short-relative+0": "w ten piątek",
	"field-fri-short-relative+1": "w przyszły piątek",
	"days-standAlone-short": [
		"nie",
		"pon",
		"wto",
		"śro",
		"czw",
		"pią",
		"sob"
	],
	"field-week-short-relative+-1": "w zeszłym tyg.",
	"months-standAlone-abbr-leap": "Adar II",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "godz.",
	"field-zone-short": "str. czasowa",
	"quarters-format-abbr": [
		"I kw.",
		"II kw.",
		"III kw.",
		"IV kw."
	],
	"field-month-narrow": "mc",
	"field-hour-narrow": "g.",
	"field-fri-narrow-relative+-1": "w zeszły piątek",
	"field-year-relative+0": "w tym roku",
	"field-year-relative+1": "w przyszłym roku",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "w zeszły piątek",
	"field-tue-short-relative+-1": "w zeszły wtorek",
	"field-minute-narrow": "min",
	"days-format-wide": [
		"niedziela",
		"poniedziałek",
		"wtorek",
		"środa",
		"czwartek",
		"piątek",
		"sobota"
	],
	"field-mon-narrow-relative+0": "w ten poniedziałek",
	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
	"field-year-short-relative+-1": "w zeszłym roku",
	"field-zone": "strefa czasowa",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-weekOfMonth-narrow": "tydz. mies.",
	"field-weekday-narrow": "dz. tyg.",
	"months-standAlone-wide-leap": "Adar II",
	"field-quarter-narrow": "kw.",
	"field-sun-short-relative+-1": "w zeszłą niedzielę",
	"field-day-relative+-1": "wczoraj",
	"field-day-relative+-2": "przedwczoraj",
	"field-weekday-short": "dzień tyg.",
	"days-format-abbr": [
		"niedz.",
		"pon.",
		"wt.",
		"śr.",
		"czw.",
		"pt.",
		"sob."
	],
	"field-sun-relative+0": "w tę niedzielę",
	"field-sun-relative+1": "w przyszłą niedzielę",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dz.",
	"field-week-narrow": "tydz.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "w ten piątek",
	"field-fri-narrow-relative+1": "w przyszły piątek"
}
//end v1.x content
);
